Weekday

Enum Weekday 

pub enum Weekday {
    Mon,
    Tue,
    Wed,
    Thu,
    Fri,
    Sat,
    Sun,
}
A day of the week, from Monday to Sunday (ISO 8601 convention: the week starts on Monday).

API aligned with chrono::Weekday: same variants, same methods.

Variants



Mon



Tue



Wed



Thu



Fri



Sat



Sun

Implementations

Source

impl Weekday

pub const fn succ(&self) -> Weekday

The next day (wraps around after Sunday).

pub const fn pred(&self) -> Weekday

The previous day (wraps around before Monday).

pub const fn num_days_from_monday(&self) -> u32

Day number counting from Monday = 0.

pub const fn num_days_from_sunday(&self) -> u32

Day number counting from Sunday = 0.

pub const fn number_from_monday(&self) -> u32

Day number counting from Monday = 1 (ISO 8601 convention).

pub const fn number_from_sunday(&self) -> u32

Day number counting from Sunday = 1.

pub const fn days_since(&self, other: Weekday) -> u32

The number of days since the previous occurrence (or the same day, if equal) of other. Always in 0..7.